@@ -13,7 +13,7 @@ my $defaults =       # config file; see ~/.ec/.ecconfig for description
    useqmail => 0,
    sendmailprog => '/usr/sbin/sendmail',
    sendmailsetfrom => 0,
-   qmail-inject => '',
+   qmailinjectpath => '',
    sigfile => '.signature',
    usesig => 1,
    mailspooldir => '/var/spool/mail',
@@ -24,8 +24,8 @@ my $defaults =       # config file; see ~/.ec/.ecconfig for description
    helpfile => '.ec/ec.help',
    trashdays => 2,
    pollinterval => 600000,
-   senderlen => 20,
-   datelen => 26,
+   senderwidth => 40,
+   datewidth => 20,
    fccfile => '',
    quotestring => '> ',
    senderlen => 25,
@@ -133,7 +133,7 @@ sub content {
     open FILE, $file or
       die "Couldn't open $file: ".$!."\n";
     while (defined ($l=<FILE>)) {
-      chop $l;
+      chomp $l;
       push @contents, ($l);
     }
     close FILE;
